Skip to contents

Downloads and tidies the HMRC Corporation Tax Statistics annual publication, reporting receipts broken down by tax type for the most recent six financial years. Published annually in September.

Usage

hmrc_corporation_tax(cache = TRUE)

Arguments

cache

Logical. Use cached file if available (default TRUE).

Value

An hmrc_tbl with columns tax_year, type, description, receipts_gbp_m.

Details

Some levies (e.g. Residential Property Developer Tax, Electricity Generators Levy) were introduced mid-series and have NA values for earlier years.

Examples

# \donttest{
op <- options(hmrc.cache_dir = file.path(tempdir(), "hmrc"))
try({
  ct <- hmrc_corporation_tax()
  ct[ct$type == "all_corporate_taxes", ]
})
#>  Resolving download URL from GOV.UK Content API
#>  Resolving download URL from GOV.UK Content API [514ms]
#> 
#>  Resolving download URL from GOV.UK Content API
#>  Resolving download URL from GOV.UK Content API [117ms]
#> 
#>  Downloading data file
#>  Downloading data file [177ms]
#> 
#>  Parsing data
#>  Parsing data [46ms]
#> 
#> # Corporation Tax statistics
#> # Source: https://www.gov.uk/government/statistics/corporation-tax-statistics-2025
#> # Fetched 2026-09-13 19:24:15 UTC | Vintage: latest | Cells: cash | Freq: annual | 6 rows x 4 cols
#> 
#>   tax_year                type         description receipts_gbp_m
#> 1  2019-20 all_corporate_taxes All Corporate Taxes          66025
#> 2  2020-21 all_corporate_taxes All Corporate Taxes          54238
#> 3  2021-22 all_corporate_taxes All Corporate Taxes          67548
#> 4  2022-23 all_corporate_taxes All Corporate Taxes          84595
#> 5  2023-24 all_corporate_taxes All Corporate Taxes          93675
#> 6  2024-25 all_corporate_taxes All Corporate Taxes          97161
options(op)
# }