Skip to contents

Downloads and tidies HMRC Table 12.1a of the Inheritance Tax Liabilities Statistics: numbers of estates, tax due, average tax, and average effective tax rate, broken down by net-estate band, for the latest published year of death. Published annually in July, about two years after the end of the year of death because estates take time to settle.

Usage

hmrc_inheritance_tax(cache = TRUE)

Arguments

cache

Logical. Use cached file if available (default TRUE).

Value

An hmrc_tbl (long format) with columns:

tax_year

Character. Year of death, e.g. "2022-23".

estate_band_lower_gbp

Numeric. Lower limit of the net-estate band in pounds.

estate_band

Character. Plain-English label, e.g. "GBP 0-100k", "Total".

measure

Character. One of "number_not_taxed", "number_taxed", "tax_due_gbp_m", "avg_tax_gbp", "effective_rate_pct" (in per cent).

value

Numeric. Value, with [z] (no tax due to NRB) and [c] (disclosure suppression) returned as NA.

Examples

# \donttest{
op <- options(hmrc.cache_dir = file.path(tempdir(), "hmrc"))
try({
  iht <- hmrc_inheritance_tax()
  iht[iht$estate_band == "Total", ]
})
#>  Resolving download URL from GOV.UK Content API
#>  Resolving download URL from GOV.UK Content API [486ms]
#> 
#>  Downloading data file
#>  Downloading data file [418ms]
#> 
#>  Parsing data
#>  Parsing data [15ms]
#> 
#> # Inheritance Tax liabilities statistics (Table 12.1a)
#> # Source: https://www.gov.uk/government/statistics/inheritance-tax-liabilities-statistics
#> # Fetched 2026-09-13 19:24:20 UTC | Vintage: latest | Cells: liabilities | Freq: annual | 5 rows x 5 cols
#> 
#>    tax_year estate_band_lower_gbp estate_band            measure  value
#> 91  2023-24                    NA       Total        avg_tax_gbp 231000
#> 92  2023-24                    NA       Total effective_rate_pct     13
#> 93  2023-24                    NA       Total   number_not_taxed  38000
#> 94  2023-24                    NA       Total       number_taxed  30400
#> 95  2023-24                    NA       Total      tax_due_gbp_m   7030
options(op)
# }