Skip to contents

Returns a data frame describing all tax and duty heads available in hmrc_tax_receipts(). No network connection is required: the data is bundled with the package.

Usage

hmrc_list_tax_heads()

Value

A data frame with columns:

tax_head

Character. Identifier used in the tax argument of hmrc_tax_receipts().

description

Character. Plain-English description.

category

Character. Broad grouping.

available_from

Character. First year with receipts in HMRC's monthly table at the package release (NA if none in the current window).

Examples

hmrc_list_tax_heads()
#>                              tax_head
#> 1                      total_receipts
#> 2                     total_paid_over
#> 3                          income_tax
#> 4                   capital_gains_tax
#> 5                     inheritance_tax
#> 6                 apprenticeship_levy
#> 7                          nics_total
#> 8                       nics_employer
#> 9                       nics_employee
#> 10                 nics_self_employed
#> 11                                vat
#> 12                    corporation_tax
#> 13                          bank_levy
#> 14                     bank_surcharge
#> 15                   bank_payroll_tax
#> 16               diverted_profits_tax
#> 17               digital_services_tax
#> 18 residential_property_developer_tax
#> 19                energy_profits_levy
#> 20        electricity_generators_levy
#> 21                economic_crime_levy
#> 22              petroleum_revenue_tax
#> 23                          fuel_duty
#> 24                  stamp_duty_shares
#> 25                               sdlt
#> 26                               ated
#> 27                       tobacco_duty
#> 28                       spirits_duty
#> 29                          beer_duty
#> 30                          wine_duty
#> 31                         cider_duty
#> 32                    gambling_duties
#> 33                 air_passenger_duty
#> 34              insurance_premium_tax
#> 35                       landfill_tax
#> 36                climate_change_levy
#> 37                    aggregates_levy
#> 38                   soft_drinks_levy
#> 39              plastic_packaging_tax
#> 40                     customs_duties
#> 41                      miscellaneous
#> 42                          penalties
#>                                                             description
#> 1                                                   Total HMRC receipts
#> 2  Total paid over to the Consolidated Fund and National Insurance Fund
#> 3                                 Income Tax (PAYE and Self Assessment)
#> 4                                                     Capital Gains Tax
#> 5                                                       Inheritance Tax
#> 6                                                   Apprenticeship Levy
#> 7                        National Insurance Contributions (all classes)
#> 8            National Insurance Contributions - employer (Class 1 PAYE)
#> 9            National Insurance Contributions - employee (Class 1 PAYE)
#> 10       National Insurance Contributions - self-employed (Class 2 & 4)
#> 11                                                      Value Added Tax
#> 12                                 Corporation Tax (including offshore)
#> 13                                                            Bank Levy
#> 14                                                       Bank Surcharge
#> 15                                                     Bank Payroll Tax
#> 16                                                 Diverted Profits Tax
#> 17                                                 Digital Services Tax
#> 18                                   Residential Property Developer Tax
#> 19                                                  Energy Profits Levy
#> 20                                          Electricity Generators Levy
#> 21                                                  Economic Crime Levy
#> 22                                                Petroleum Revenue Tax
#> 23                                   Hydrocarbon Oil Duties (Fuel Duty)
#> 24                          Stamp taxes on shares (SDRT and Stamp Duty)
#> 25                                                  Stamp Duty Land Tax
#> 26                                    Annual Tax on Enveloped Dwellings
#> 27                                                       Tobacco Duties
#> 28                                                       Spirits Duties
#> 29                                                          Beer Duties
#> 30                                            Wine and Made-Wine Duties
#> 31                                               Cider and Perry Duties
#> 32                                            Betting and Gaming Duties
#> 33                                                   Air Passenger Duty
#> 34                                                Insurance Premium Tax
#> 35                                                         Landfill Tax
#> 36                                                  Climate Change Levy
#> 37                                                      Aggregates Levy
#> 38                                            Soft Drinks Industry Levy
#> 39                                                Plastic Packaging Tax
#> 40                                                       Customs Duties
#> 41                                               Miscellaneous receipts
#> 42                                               Penalties and interest
#>       category available_from
#> 1        total           2017
#> 2        total           2017
#> 3       income           2017
#> 4       income           2017
#> 5       income           2017
#> 6       income           2017
#> 7         nics           2017
#> 8         nics           2017
#> 9         nics           2017
#> 10        nics           2017
#> 11 consumption           2017
#> 12      income           2017
#> 13      income           2017
#> 14      income           2017
#> 15      income           <NA>
#> 16      income           2018
#> 17      income           2022
#> 18      income           2022
#> 19      income           2022
#> 20      income           2023
#> 21      income           2023
#> 22      income           2017
#> 23 consumption           2017
#> 24    property           2017
#> 25    property           2017
#> 26    property           2017
#> 27 consumption           2017
#> 28 consumption           2017
#> 29 consumption           2017
#> 30 consumption           2017
#> 31 consumption           2017
#> 32 consumption           2017
#> 33 consumption           2017
#> 34 consumption           2017
#> 35 environment           2017
#> 36 environment           2017
#> 37 environment           2017
#> 38 consumption           2018
#> 39 consumption           2022
#> 40       other           2017
#> 41       other           <NA>
#> 42       other           2017