Downloads and tidies the HMRC Hydrocarbon Oils Bulletin, which reports monthly fuel duty receipts. Data runs from January 1990 to the most recent published month, updated twice per year (January and July).
Value
An hmrc_tbl with columns date, fuel, description,
receipts_gbp_m, and provisional (logical, TRUE for months HMRC
flags as provisional).
Details
petrol and diesel are HMRC's "Total petrol" and "Total diesel"
columns. other is the sum of fuel oil, gas oil and road fuel gases.
total is HMRC's total hydrocarbon oils receipts.
See also
Other data fetchers:
hmrc_capital_gains(),
hmrc_corporation_tax(),
hmrc_creative_industries(),
hmrc_income_tax_stats(),
hmrc_inheritance_tax(),
hmrc_patent_box(),
hmrc_property_transactions(),
hmrc_rd_credits(),
hmrc_stamp_duty(),
hmrc_tax_gap(),
hmrc_tax_receipts(),
hmrc_tobacco_duties(),
hmrc_vat()
Examples
# \donttest{
op <- options(hmrc.cache_dir = file.path(tempdir(), "hmrc"))
try({
fuel <- hmrc_fuel_duties(fuel = "total", start = "2024-01")
head(fuel)
})
#> ℹ Resolving download URL from GOV.UK Content API
#> ✔ Resolving download URL from GOV.UK Content API [198ms]
#>
#> ℹ Downloading data file
#> ✔ Downloading data file [353ms]
#>
#> ℹ Parsing data
#> ✔ Parsing data [108ms]
#>
#> # Hydrocarbon Oils Bulletin (fuel duties)
#> # Source: https://www.gov.uk/government/statistics/hydrocarbon-oils-bulletin
#> # Fetched 2026-09-13 19:24:18 UTC | Vintage: latest | Cells: cash | Freq: monthly | 6 rows x 5 cols
#>
#> date fuel description receipts_gbp_m provisional
#> 1 2024-01-01 total Total hydrocarbon oils receipts 1834.276 FALSE
#> 2 2024-02-01 total Total hydrocarbon oils receipts 2107.229 FALSE
#> 3 2024-03-01 total Total hydrocarbon oils receipts 2022.634 FALSE
#> 4 2024-04-01 total Total hydrocarbon oils receipts 1903.166 FALSE
#> 5 2024-05-01 total Total hydrocarbon oils receipts 2044.154 FALSE
#> 6 2024-06-01 total Total hydrocarbon oils receipts 2066.890 FALSE
options(op)
# }