Download HMRC Income Tax liabilities by income range
Source:R/hmrc_income_tax_stats.R
hmrc_income_tax_stats.RdDownloads and tidies HMRC Table 2.5, which reports the number of Income Tax payers and their liabilities grouped by total income range, for each available tax year. Numbers of taxpayers are in thousands; amounts are in millions of pounds unless otherwise noted. Published annually in May/June.
Value
An hmrc_tbl with columns tax_year, income_range,
income_lower_gbp, taxpayers_thousands, total_income_gbp_m,
tax_liability_gbp_m, average_rate_pct, average_tax_gbp.
Details
The earliest tax year with outturn data is based on the Survey of Personal
Incomes; later years are projected estimates. Values suppressed for small
sample sizes are returned as NA.
Examples
# \donttest{
op <- options(hmrc.cache_dir = tempdir())
hmrc_income_tax_stats()
#> ℹ Resolving download URL from GOV.UK Content API
#> ✔ Resolving download URL from GOV.UK Content API [582ms]
#>
#> ℹ Downloading data file
#> ✔ Downloading data file [761ms]
#>
#> ℹ Parsing data
#> New names:
#> • `` -> `...1`
#> • `` -> `...2`
#> • `` -> `...3`
#> • `` -> `...4`
#> • `` -> `...5`
#> • `` -> `...6`
#> • `` -> `...7`
#> • `` -> `...8`
#> • `` -> `...9`
#> • `` -> `...10`
#> • `` -> `...11`
#> • `` -> `...12`
#> • `` -> `...13`
#> • `` -> `...14`
#> New names:
#> • `` -> `...1`
#> • `` -> `...2`
#> • `` -> `...3`
#> • `` -> `...4`
#> • `` -> `...5`
#> • `` -> `...6`
#> • `` -> `...7`
#> • `` -> `...8`
#> • `` -> `...9`
#> • `` -> `...10`
#> • `` -> `...11`
#> • `` -> `...12`
#> • `` -> `...13`
#> • `` -> `...14`
#> New names:
#> • `` -> `...1`
#> • `` -> `...2`
#> • `` -> `...3`
#> • `` -> `...4`
#> • `` -> `...5`
#> • `` -> `...6`
#> • `` -> `...7`
#> • `` -> `...8`
#> • `` -> `...9`
#> • `` -> `...10`
#> • `` -> `...11`
#> • `` -> `...12`
#> • `` -> `...13`
#> • `` -> `...14`
#> New names:
#> • `` -> `...1`
#> • `` -> `...2`
#> • `` -> `...3`
#> • `` -> `...4`
#> • `` -> `...5`
#> • `` -> `...6`
#> • `` -> `...7`
#> • `` -> `...8`
#> • `` -> `...9`
#> • `` -> `...10`
#> • `` -> `...11`
#> • `` -> `...12`
#> • `` -> `...13`
#> • `` -> `...14`
#> ✔ Parsing data [431ms]
#>
#> # Income Tax liabilities by income range (Table 2.5)
#> # Source: https://www.gov.uk/government/statistics/income-tax-liabilities-by-income-range
#> # Fetched 2026-04-26 13:15:45 UTC | Vintage: latest | Cells: liabilities | Freq: annual | 48 rows x 8 cols
#>
#> tax_year income_range income_lower_gbp taxpayers_thousands
#> 1 2022-23 12570 12570 2870
#> 2 2022-23 15000 15000 5740
#> 3 2022-23 20000 20000 9960
#> 4 2022-23 30000 30000 9710
#> 5 2022-23 50000 50000 4850
#> 6 2022-23 100000 100000 754
#> 7 2022-23 150000 150000 266
#> 8 2022-23 200000 200000 276
#> 9 2022-23 500000 500000 49
#> 10 2022-23 1000000 1000000 16
#> 11 2022-23 2000000+ 2000000 9
#> 12 2022-23 All Ranges NA 34500
#> 13 2023-24 12570 12570 2960
#> 14 2023-24 15000 15000 5490
#> 15 2023-24 20000 20000 10200
#> 16 2023-24 30000 30000 10600
#> 17 2023-24 50000 50000 5800
#> 18 2023-24 100000 100000 922
#> 19 2023-24 150000 150000 315
#> 20 2023-24 200000 200000 312
#> 21 2023-24 500000 500000 54
#> 22 2023-24 1000000 1000000 18
#> 23 2023-24 2000000+ 2000000 9
#> 24 2023-24 All Ranges NA 36600
#> 25 2024-25 12570 12570 2890
#> 26 2024-25 15000 15000 5470
#> 27 2024-25 20000 20000 10200
#> 28 2024-25 30000 30000 11300
#> 29 2024-25 50000 50000 6380
#> 30 2024-25 100000 100000 1030
#> 31 2024-25 150000 150000 346
#> 32 2024-25 200000 200000 344
#> 33 2024-25 500000 500000 58
#> 34 2024-25 1000000 1000000 19
#> 35 2024-25 2000000+ 2000000 10
#> 36 2024-25 All Ranges NA 38000
#> 37 2025-26 12570 12570 2760
#> 38 2025-26 15000 15000 5490
#> 39 2025-26 20000 20000 10200
#> 40 2025-26 30000 30000 11900
#> 41 2025-26 50000 50000 6850
#> 42 2025-26 100000 100000 1120
#> 43 2025-26 150000 150000 366
#> 44 2025-26 200000 200000 375
#> 45 2025-26 500000 500000 62
#> 46 2025-26 1000000 1000000 21
#> 47 2025-26 2000000+ 2000000 11
#> 48 2025-26 All Ranges NA 39100
#> total_income_gbp_m tax_liability_gbp_m average_rate_pct average_tax_gbp
#> 1 39300 607 1.5 212
#> 2 100000 4930 4.9 859
#> 3 246000 22000 8.9 2210
#> 4 373000 45700 12.3 4700
#> 5 319000 60100 18.8 12400
#> 6 90200 26300 29.1 34800
#> 7 45500 15200 33.5 57300
#> 8 79300 29800 37.6 108000
#> 9 33200 13400 40.4 273000
#> 10 22300 9020 40.4 547000
#> 11 45400 17900 39.5 2090000
#> 12 1390000 245000 17.6 7100
#> 13 40600 627 1.5 212
#> 14 95700 4640 4.9 845
#> 15 251000 22500 9.0 2220
#> 16 406000 50200 12.4 4740
#> 17 380000 71300 18.7 12300
#> 18 110000 32000 29.1 34700
#> 19 54000 18400 34.0 58300
#> 20 89200 33900 38.0 109000
#> 21 36200 14700 40.6 275000
#> 22 24200 9840 40.7 552000
#> 23 49100 19400 39.6 2110000
#> 24 1540000 277000 18.1 7580
#> 25 39700 640 1.6 222
#> 26 95400 4680 4.9 855
#> 27 252000 22800 9.0 2240
#> 28 435000 54000 12.4 4780
#> 29 420000 79100 18.9 12400
#> 30 122000 35800 29.3 34900
#> 31 59400 20200 34.1 58500
#> 32 98300 37400 38.0 109000
#> 33 39100 15900 40.7 276000
#> 34 26000 10600 40.8 554000
#> 35 52800 20900 39.6 2120000
#> 36 1640000 302000 18.4 7950
#> 37 37900 631 1.7 229
#> 38 95600 4710 4.9 859
#> 39 252000 23000 9.1 2260
#> 40 458000 57200 12.5 4810
#> 41 452000 85600 18.9 12500
#> 42 133000 39000 29.4 35000
#> 43 62800 21400 34.1 58400
#> 44 107000 40700 38.0 109000
#> 45 41900 17100 40.8 276000
#> 46 27900 11400 40.9 555000
#> 47 56600 22400 39.6 2120000
#> 48 1730000 323000 18.7 8270
hmrc_income_tax_stats(tax_year = "2023-24")
#> ℹ Resolving download URL from GOV.UK Content API
#> ✔ Resolving download URL from GOV.UK Content API [25ms]
#>
#> ℹ Using cached file
#> ✔ Using cached file [6ms]
#>
#> ℹ Parsing data
#> New names:
#> • `` -> `...1`
#> • `` -> `...2`
#> • `` -> `...3`
#> • `` -> `...4`
#> • `` -> `...5`
#> • `` -> `...6`
#> • `` -> `...7`
#> • `` -> `...8`
#> • `` -> `...9`
#> • `` -> `...10`
#> • `` -> `...11`
#> • `` -> `...12`
#> • `` -> `...13`
#> • `` -> `...14`
#> New names:
#> • `` -> `...1`
#> • `` -> `...2`
#> • `` -> `...3`
#> • `` -> `...4`
#> • `` -> `...5`
#> • `` -> `...6`
#> • `` -> `...7`
#> • `` -> `...8`
#> • `` -> `...9`
#> • `` -> `...10`
#> • `` -> `...11`
#> • `` -> `...12`
#> • `` -> `...13`
#> • `` -> `...14`
#> New names:
#> • `` -> `...1`
#> • `` -> `...2`
#> • `` -> `...3`
#> • `` -> `...4`
#> • `` -> `...5`
#> • `` -> `...6`
#> • `` -> `...7`
#> • `` -> `...8`
#> • `` -> `...9`
#> • `` -> `...10`
#> • `` -> `...11`
#> • `` -> `...12`
#> • `` -> `...13`
#> • `` -> `...14`
#> New names:
#> • `` -> `...1`
#> • `` -> `...2`
#> • `` -> `...3`
#> • `` -> `...4`
#> • `` -> `...5`
#> • `` -> `...6`
#> • `` -> `...7`
#> • `` -> `...8`
#> • `` -> `...9`
#> • `` -> `...10`
#> • `` -> `...11`
#> • `` -> `...12`
#> • `` -> `...13`
#> • `` -> `...14`
#> ✔ Parsing data [449ms]
#>
#> # Income Tax liabilities by income range (Table 2.5)
#> # Source: https://www.gov.uk/government/statistics/income-tax-liabilities-by-income-range
#> # Fetched 2026-04-26 13:15:46 UTC | Vintage: latest | Cells: liabilities | Freq: annual | 12 rows x 8 cols
#>
#> tax_year income_range income_lower_gbp taxpayers_thousands
#> 1 2023-24 12570 12570 2960
#> 2 2023-24 15000 15000 5490
#> 3 2023-24 20000 20000 10200
#> 4 2023-24 30000 30000 10600
#> 5 2023-24 50000 50000 5800
#> 6 2023-24 100000 100000 922
#> 7 2023-24 150000 150000 315
#> 8 2023-24 200000 200000 312
#> 9 2023-24 500000 500000 54
#> 10 2023-24 1000000 1000000 18
#> 11 2023-24 2000000+ 2000000 9
#> 12 2023-24 All Ranges NA 36600
#> total_income_gbp_m tax_liability_gbp_m average_rate_pct average_tax_gbp
#> 1 40600 627 1.5 212
#> 2 95700 4640 4.9 845
#> 3 251000 22500 9.0 2220
#> 4 406000 50200 12.4 4740
#> 5 380000 71300 18.7 12300
#> 6 110000 32000 29.1 34700
#> 7 54000 18400 34.0 58300
#> 8 89200 33900 38.0 109000
#> 9 36200 14700 40.6 275000
#> 10 24200 9840 40.7 552000
#> 11 49100 19400 39.6 2110000
#> 12 1540000 277000 18.1 7580
options(op)
# }